Seantis Placemap
================

Shows placemarks from multiple maps in one map, by combining kml-documents from
multiple urls.

Commisioned by `Onegov`_ as a way to have simple maps for municipalities to
show of scrap yards, barbecue pits and playgrounds.

This modules does not offer the ability to define placemarks, instead it gathers
them from different sources that offer KML documents.

Requirements
------------

-  Python 2.7
-  Plone 4.3+
-  Linux / Posix ( Windows may or may not work )

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.placemap.png   
  :target: https://travis-ci.org/seantis/seantis.placemap
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.placemap/badge.png?branch=master
  :target: https://coveralls.io/r/seantis/seantis.placemap?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://pypip.in/v/seantis.placemap/badge.png
  :target: https://crate.io/packages/seantis.placemap
  :alt: Latest PyPI Release

License
-------
seantis.placemap is released under GPL v2


.. -> external links

.. _OneGov: http://onegov.ch/